@@ -27,6 +27,9 @@ export ALGE_APP_SECRET_KEY="4dbgj9((dey#0!1ie@spppfbvj!2av6s1-16)1xp70ss"
 export ALGE_PUBLIC_ENDPOINT="clinicapp-alge.appspot.com"
 export ALGE_HOST="/cloudsql/clinicapp-alge:us-central1:alge-db-a"
 
+export PYPI_USER=iGlobalHealth-EPFL
+export PYPI_PASSWORD=iGHpypiPYPI
+
 #env_variables:
 #  ALGE_GC_RUN: true
 #  ALGE_PUBLIC_ENDPOINT: clinicapp-alge.appspot.com
